mailr7238 - /1.3/specific_fns/base_class.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on September 24, 2008 - 16:10:
Author: bugman
Date: Wed Sep 24 16:10:56 2008
New Revision: 7238

URL: http://svn.gna.org/viewcvs/relax?rev=7238&view=rev
Log:
Changed model_loop() to return the spin container.


Modified:
    1.3/specific_fns/base_class.py

Modified: 1.3/specific_fns/base_class.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/base_class.py?rev=7238&r1=7237&r2=7238&view=diff
==============================================================================
--- 1.3/specific_fns/base_class.py (original)
+++ 1.3/specific_fns/base_class.py Wed Sep 24 16:10:56 2008
@@ -115,22 +115,21 @@
         """Default generator method for looping over the models.
 
         In this case only a single model per spin system is assumed.  Hence 
the yielded data is the
-        spin ID string.
-
-
-        @return:    Information about the model which for this analysis is 
the spin identification
-                    string.
-        @rtype:     str
+        spin container object.
+
+
+        @return:    Information about the model which for this analysis is 
the spin container.
+        @rtype:     SpinContainer instance
         """
 
         # Loop over the sequence.
-        for spin, spin_id in spin_loop(return_id=True):
+        for spin in spin_loop():
             # Skip deselected spins.
             if not spin.select:
                 continue
 
-            # Yield the spin ID string.
-            yield spin_id
+            # Yield the spin container.
+            yield spin
 
 
     def num_instances(self):




Related Messages


Powered by MHonArc, Updated Wed Sep 24 16:20:03 2008